--
-- RopeBreakdown
-- Specialization for New Holland BB 980 from Strawmod to get it breakable due to a lack of rope.
--
-- @author  	Benjamin Biot (J&B Modding)
-- @version 	v1.0
-- @date  		30/11/10
--

RopeBreakdown = {};

function RopeBreakdown.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Baler, specializations);
end;

function RopeBreakdown:load(savegame)
	self.SetDoorPanel= SpecializationUtil.callSpecializationsFunction("SetDoorPanel");
	self.SetHasRopes= SpecializationUtil.callSpecializationsFunction("SetHasRopes");
	-- Animation --
	self.DoorPanelAnimation = getXMLString(self.xmlFile, "vehicle.DoorPanel#animationName");	
	self.DoorPanel = true;		
	-- Ropes management --
	self.Ropes = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.Ropes#index"));
	self.RopesCapacity = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.Ropes#Capacity"), 4);
	self.hasRopes = true;
	self.isLoaded = true;
	-- Sound for "no Ropes " --
    NoRopeSoundFile = Utils.getFilename("Sounds/NoRope.wav", self.baseDirectory);
    self.NoRopeSoundId = createSample("NoRopeSound");
    loadSample(self.NoRopeSoundId, NoRopeSoundFile, false);
    self.NoRopePlaying = false;

	
end;

function RopeBreakdown:delete()
    if self.NoRopeSound ~= nil then
        delete(self.NoRopeSound);
    end;
end;

function RopeBreakdown:readStream(streamId, connection)
    self:SetDoorPanel(streamReadBool(streamId), true);
    self:SetHasRopes(streamReadBool(streamId), true);
end;

function RopeBreakdown:writeStream(streamId, connection)
    streamWriteBool(streamId, self.DoorPanel);
    streamWriteBool(streamId, self.isLoaded);
end;

function RopeBreakdown:readUpdateStream(streamId, timestamp, connection)
end;

function RopeBreakdown:writeUpdateStream(streamId, connection, dirtyMask)
end;

function RopeBreakdown:mouseEvent(posX, posY, isDown, isUp, button)
end;

function RopeBreakdown:keyEvent(unicode, sym, modifier, isDown)
end;

function RopeBreakdown:update(dt)	
	-- Manage key events --
	if self.inrange then
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA3) then
			self:SetDoorPanel(not self.DoorPanel);
		end;
		if not self.isLoaded then
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
				self:SetHasRopes(true);
			end;
		end;
	end;
	-- trigger the breakdown --
	if self.NoRopesBalesCount >= self.RopesCapacity then
		self:SetHasRopes(false);
	end;		
	-- Display key when in range --
	if self.inrange then
		if self.DoorPanel then
			g_currentMission:addHelpButtonText(string.format(g_i18n:getText("OPEN_DOOR"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA3);
		else
			g_currentMission:addHelpButtonText(string.format(g_i18n:getText("CLOSE_DOOR"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA3);
			if not self.isLoaded then
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("RELOAD_ROPES"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA2);
			end;
		end;
	end;	
end;

function RopeBreakdown:updateTick(dt)	
	if self.attacherVehicle and g_currentMission.player ~= nil then
		-- Getting the distance between the player and the implement 
		local nearestDistance = 4.0; --max distance allowed
		local px, py, pz = getWorldTranslation(self.rootNode); 
		local vx, vy, vz = getWorldTranslation(g_currentMission.player.rootNode);
		local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);	
		if distance < nearestDistance then
			self.inrange = true; 
		else
			self.inrange = false; 
		end;
	end;
end;

function RopeBreakdown:SetDoorPanel(isDoorPanel,noEventSend)
	SetDoorPanelEvent.sendEvent(self, isDoorPanel, noEventSend);
	-- Play doorPanel animation if inRange --
		if isDoorPanel then
			if self.DoorPanelAnimation ~= nil and self.playAnimation ~= nil then
				self:playAnimation(self.DoorPanelAnimation, -1, nil, true);
				self.DoorPanel = true;
			end;
		else
			if self.DoorPanelAnimation ~= nil and self.playAnimation ~= nil then
				self:playAnimation(self.DoorPanelAnimation, 1, nil, true);
				self.DoorPanel = false;
			end;
		end;
end;

function RopeBreakdown:SetHasRopes(isLoaded,noEventSend)
	self.isLoaded = isLoaded;
	SetHasRopesEvent.sendEvent(self, self.isLoaded, noEventSend);
	if self.isLoaded then
		self.NoRopesBalesCount = 0;
		setVisibility(self.Ropes, true);
		if self.NoRopePlaying then
			stopSample(self.NoRopeSoundId);
			self.NoRopePlaying = false;
		end;
	else
		setVisibility(self.Ropes, false);	
		self:setPickupState(false, true);
		if self:getIsActiveForSound() then
			if not self.NoRopePlaying then
				playSample(self.NoRopeSoundId, 1, 1, 0);
				self.NoRopePlaying = true;
			end;
		end;
	end;
end;

function RopeBreakdown:draw()
	setTextBold(true);
	setTextColor(0, 0, 0, 1.0);
	if self.HUD then	
		if not self.isLoaded then
			renderText(0.342, 0.918, 0.015, string.format(g_i18n:getText("NO_ROPES"), self.typeDesc));
		end;
	end;
end;

